Module terminal

Module terminal 

A standard terminal frontend that uses ANSI escape sequences to render progress bars in-place.

This module provides the TerminalFrontend struct, which is responsible for converting a ProgressSnapshot into a human-readable, visual representation suitable for standard output streams (e.g., stderr or stdout).

Structs

TerminalFrontend
A standard terminal frontend that uses ANSI escape sequences.
Theme
A theme for customizing the appearance of the TerminalFrontend.