pub trait Frontend {
// Required methods
fn render(&mut self, snapshot: &ProgressSnapshot) -> Result<()>;
fn render_stack(
&mut self,
stack_snapshot: &ProgressStackSnapshot,
) -> Result<()>;
fn clear(&mut self) -> Result<()>;
fn finish(&mut self) -> Result<()>;
}Expand description
A trait for rendering progress state.
By implementing this trait, you can direct progress updates to any output mechanism: a terminal, a GUI framework, a log file, or a network socket.
Required Methods
Sourcefn render(&mut self, snapshot: &ProgressSnapshot) -> Result<()>
fn render(&mut self, snapshot: &ProgressSnapshot) -> Result<()>
Renders a single progress snapshot.
Sourcefn render_stack(&mut self, stack_snapshot: &ProgressStackSnapshot) -> Result<()>
fn render_stack(&mut self, stack_snapshot: &ProgressStackSnapshot) -> Result<()>
Renders a snapshot of a progress stack (multiple trackers).